==> aliyun-python-sdk-foas-2.3.3.tar.gz: aliyun-python-sdk-foas-2.3.3/aliyunsdkfoas/request/v20181111/GetRawPlanJsonRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkfoas.endpoint import endpoint_data

class GetRawPlanJsonRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'foas', '2018-11-11', 'GetRawPlanJson','foas')
		self.set_protocol_type('https')
		self.set_uri_pattern('/api/v2/projects/[projectName]/jobs/[jobName]/planjson')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_projectName(self):
		return self.get_path_params().get('projectName')

	def set_projectName(self,projectName):
		self.add_path_param('projectName',projectName)

	def get_expectedGB(self):
		return self.get_query_params().get('expectedGB')

	def set_expectedGB(self,expectedGB):
		self.add_query_param('expectedGB',expectedGB)

	def get_expectedCore(self):
		return self.get_query_params().get('expectedCore')

	def set_expectedCore(self,expectedCore):
		self.add_query_param('expectedCore',expectedCore)

	def get_jobName(self):
		return self.get_path_params().get('jobName')

	def set_jobName(self,jobName):
		self.add_path_param('jobName',jobName)

	def get_autoconfEnable(self):
		return self.get_query_params().get('autoconfEnable')

	def set_autoconfEnable(self,autoconfEnable):
		self.add_query_param('autoconfEnable',autoconfEnable)

==> aliyun-python-sdk-foas-2.11.1.tar.gz: aliyun-python-sdk-foas-2.11.1/aliyunsdkfoas/request/v20181111/GetRawPlanJsonRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkfoas.endpoint import endpoint_data

class GetRawPlanJsonRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'foas', '2018-11-11', 'GetRawPlanJson','foas')
		self.set_protocol_type('https')
		self.set_uri_pattern('/api/v2/projects/[projectName]/jobs/[jobName]/planjson')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_projectName(self):
		return self.get_path_params().get('projectName')

	def set_projectName(self,projectName):
		self.add_path_param('projectName',projectName)

	def get_expectedGB(self):
		return self.get_query_params().get('expectedGB')

	def set_expectedGB(self,expectedGB):
		self.add_query_param('expectedGB',expectedGB)

	def get_expectedCore(self):
		return self.get_query_params().get('expectedCore')

	def set_expectedCore(self,expectedCore):
		self.add_query_param('expectedCore',expectedCore)

	def get_AdvisorAction(self):
		return self.get_query_params().get('AdvisorAction')

	def set_AdvisorAction(self,AdvisorAction):
		self.add_query_param('AdvisorAction',AdvisorAction)

	def get_jobName(self):
		return self.get_path_params().get('jobName')

	def set_jobName(self,jobName):
		self.add_path_param('jobName',jobName)

	def get_autoconfEnable(self):
		return self.get_query_params().get('autoconfEnable')

	def set_autoconfEnable(self,autoconfEnable):
		self.add_query_param('autoconfEnable',autoconfEnable)
